Fix hipBusBW sample for P2P bidirectional test
[ROCm/clr commit: 828e62fe4f]
This commit is contained in:
@@ -812,6 +812,7 @@ void RunBenchmark_P2P_Bidir(ResultDatabase& resultDB) {
|
|||||||
hipSetDevice(currentGpu);
|
hipSetDevice(currentGpu);
|
||||||
hipMalloc((void**)¤tGpuMem[0], sizeof(float) * numMaxFloats);
|
hipMalloc((void**)¤tGpuMem[0], sizeof(float) * numMaxFloats);
|
||||||
hipMalloc((void**)¤tGpuMem[1], sizeof(float) * numMaxFloats);
|
hipMalloc((void**)¤tGpuMem[1], sizeof(float) * numMaxFloats);
|
||||||
|
enablePeer2Peer(peerGpu,currentGpu);
|
||||||
|
|
||||||
hipSetDevice(peerGpu);
|
hipSetDevice(peerGpu);
|
||||||
hipMalloc((void**)&peerGpuMem[0], sizeof(float) * numMaxFloats);
|
hipMalloc((void**)&peerGpuMem[0], sizeof(float) * numMaxFloats);
|
||||||
@@ -899,6 +900,7 @@ void RunBenchmark_P2P_Bidir(ResultDatabase& resultDB) {
|
|||||||
}
|
}
|
||||||
|
|
||||||
disablePeer2Peer(currentGpu, peerGpu);
|
disablePeer2Peer(currentGpu, peerGpu);
|
||||||
|
disablePeer2Peer(peerGpu, currentGpu);
|
||||||
|
|
||||||
hipEventDestroy(start);
|
hipEventDestroy(start);
|
||||||
hipEventDestroy(stop);
|
hipEventDestroy(stop);
|
||||||
|
|||||||
Reference in New Issue
Block a user